@@ -9,13 +9,13 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
       return(NULL)
     dob = max(opt.path$env$dob) + 1L
     # die at once
-    evalOptimizationStates(learner, task, resampling, measures, NULL, bits.to.features, control, opt.path, show.info, xs, dob, dob, FALSE)
-    
-    best.i = getOptPathBestIndex(opt.path, dob=dob, ties="random")
+    evalOptimizationStatesFeatSel(learner, task, resampling, measures, bits.to.features, control, opt.path, show.info, xs, dob, dob)
+
+    best.i = getOptPathBestIndex(opt.path, dob = dob, ties = "random")
     best = getOptPathEl(opt.path, best.i)
     # best element lives one iteration longer
-    thresh = ifelse(forward, control$extra.args$alpha, control$extra.args$beta) 
-    better = compare(state, best, control, measures[[1]], thresh) 
+    thresh = ifelse(forward, control$extra.args$alpha, control$extra.args$beta)
+    better = compare(state, best, control, measures[[1]], thresh)
     # if backward step and we have too many vars we do always go to the next best state with one less var.
     if ((forward && better) || (!forward && (better || (!is.na(control$max.features) && sum(unlist(state$x)) > control$max.features)))) {
       setOptPathElEOL(opt.path, best.i, dob+1)
@@ -24,7 +24,7 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
       return(NULL)
     }
   }
-  
+
   gen.new.states.sfs = function(x) {
     xs = list()
     for (i in 1:length(x))
@@ -35,7 +35,7 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
       }
     xs
   }
-  
+
   gen.new.states.sbs = function(x) {
     xs = list()
     for (i in 1:length(x))
@@ -46,31 +46,30 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
       }
     xs
   }
-  
+
   dim = length(bit.names)
   compare = compare.diff
   method = control$extra.args$method
-  
+
   x = switch(method,
     sfs = rep(0, dim),
     sbs = rep(1, dim),
     sffs = rep(0, dim),
     sfbs = rep(1, dim),
     stop(paste("Unknown method:", method))
-  ) 
-  
+  )
+
   gen.new.states = switch(method,
     sfs = gen.new.states.sfs,
     sbs = gen.new.states.sbs,
     sffs = gen.new.states.sfs,
     sfbs = gen.new.states.sbs,
     stop(paste("Unknown method:", method))
-  ) 
-  
-  y = evalOptimizationState(learner, task, resampling, measures, NULL, bits.to.features, control, opt.path, show.info, x, FALSE)
-  state = list(x=x, y=y)
-  path = addOptPathEl(opt.path, x=as.list(x), y=y, dob=1L, eol=2L)   
-  
+  )
+  res = evalOptimizationState(learner, task, resampling, measures, NULL, bits.to.features, control, opt.path, show.info, 1L, x, FALSE)
+  state = list(x = x, y = res$y)
+  addOptPathEl(opt.path, x = as.list(x), y = res$y, dob = 1L, eol = 2L, exec.time = res$exec.time, error.message = res$errmsg)
+
   forward = (method %in% c("sfs", "sffs"))
   fail = 0
   while ((method %in% c("sfs", "sbs")  && fail == 0) || (method %in% c("sffs", "sfbs") && fail < 2)) {
@@ -88,7 +87,7 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
       gns = switch(method,
         sffs = gen.new.states.sbs,
         sfbs = gen.new.states.sfs
-      ) 
+        )
       state2 = seq.step(!forward, state, gns, compare)
       if (!is.null(state2)) {
         state = state2
@@ -98,19 +97,13 @@ selectFeaturesSequential = function(learner, task, resampling, measures, bit.nam
       }
     }
   }
-  
+
   # if last generation contains no better element, go to second to last
-  last = max(opt.path$env$dob) 
-  j = which(opt.path$env$dob == last)
-  
+  last = max(opt.path$env$dob)
+
   if (all(opt.path$env$eol[opt.path$env$dob == last] == last))
     last = last-1
-  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1]]), dob=last, ties="first")
+  i = getOptPathBestIndex(opt.path, measureAggrName(measures[[1L]]), dob = last, ties = "first")
   e = getOptPathEl(opt.path, i)
-	makeFeatSelResult(learner, control, names(e$x)[e$x == 1], e$y, opt.path)
+  makeFeatSelResult(learner, control, names(e$x)[e$x == 1], e$y, opt.path)
 }
-
-
-
-
-
