@@ -14,11 +14,13 @@
 #' @param .subset [\code{integer}]\cr
 #'   Subset of cases for training set, index the task with this.
 #'   You probably want to use \code{\link{getTaskData}} for this purpose.
+#' @param .weights [\code{numeric}]\cr
+#'   Weights for each observation.
 #' @param ... [any]\cr
 #'   Additional (hyper)parameters, which need to be passed to the underlying train function.
 #' @return [any]. Model of the underlying learner.
 #' @export
-trainLearner = function(.learner, .task, .subset,  ...) {
+trainLearner = function(.learner, .task, .subset, .weights = NULL, ...) {
   UseMethod("trainLearner")
 }
 
